braindecode.datautil.exponential_moving_standardize
===================================================

.. currentmodule:: braindecode.datautil

.. autofunction:: exponential_moving_standardize

.. include:: braindecode.datautil.exponential_moving_standardize.examples

.. raw:: html

    <div style='clear:both'></div>